==> samba-2.2.4.tar.bz2: samba-2.2.4/source/acconfig.h <==
#undef HAVE_VOLATILE
#undef HAVE_BROKEN_READDIR
#undef HAVE_C99_VSNPRINTF
#undef HAVE_ERRNO_DECL
#undef HAVE_LONGLONG
#undef HAVE_OFF64_T
#undef HAVE_REMSH
#undef HAVE_UNSIGNED_CHAR
#undef HAVE_UTIMBUF
#undef HAVE_SIG_ATOMIC_T_TYPE
#undef HAVE_SOCKLEN_T_TYPE
#undef ssize_t
#undef ino_t
#undef ssize_t
#undef loff_t
#undef offset_t
#undef aclent_t
#undef wchar_t
#undef HAVE_CONNECT
#undef HAVE_SHORT_INO_T
#undef WITH_SMBWRAPPER
#undef WITH_AFS
#undef WITH_DFS
#undef SUNOS5
#undef SUNOS4
#undef LINUX
#undef AIX
#undef BSD
#undef IRIX
#undef IRIX6
#undef HPUX
#undef QNX
#undef SCO
#undef OSF1
#undef NEXT2
#undef RELIANTUNIX
#undef HAVE_MMAP
#undef HAVE_FCNTL_LOCK
#undef HAVE_FTRUNCATE_EXTEND
#undef FTRUNCATE_NEEDS_ROOT
#undef HAVE_TRAPDOOR_UID
#undef HAVE_ROOT
#undef HAVE_GETTIMEOFDAY_TZ
#undef HAVE_SOCK_SIN_LEN
#undef STAT_READ_FILSYS
#undef STAT_STATFS2_BSIZE
#undef STAT_STATFS2_FSIZE
#undef STAT_STATFS2_FS_DATA
#undef STAT_STATFS3_OSF1
#undef STAT_STATFS4
#undef STAT_STATVFS
#undef STAT_STATVFS64
#undef HAVE_IFACE_AIX
#undef HAVE_IFACE_IFCONF
#undef HAVE_IFACE_IFREQ
#undef HAVE_CRYPT
#undef HAVE_PUTPRPWNAM
#undef HAVE_SET_AUTH_PARAMETERS
#undef WITH_SYSLOG
#undef WITH_PROFILE
#undef WITH_SSL
#undef WITH_LDAP
#undef WITH_NISPLUS
#undef WITH_TDBPWD
#undef WITH_PAM
#undef WITH_PAM_SMBPASS
#undef WITH_NISPLUS_HOME
#undef WITH_AUTOMOUNT
#undef WITH_SMBMOUNT
#undef HAVE_BROKEN_GETGROUPS
#undef REPLACE_GETPASS
#undef REPLACE_INET_NTOA
#undef HAVE_FILE_MACRO
#undef HAVE_FUNCTION_MACRO
#undef HAVE_SETRESUID_DECL
#undef HAVE_SETRESUID
#undef WITH_NETATALK
#undef WITH_UTMP
#undef WITH_MSDFS
#undef WITH_VFS
#undef HAVE_INO64_T
#undef HAVE_DEV64_T
#undef HAVE_STRUCT_FLOCK64
#undef SIZEOF_INO_T
#undef SIZEOF_OFF_T
#undef STAT_STATVFS64
#undef HAVE_LIBREADLINE
#undef HAVE_KERNEL_SHARE_MODES
#undef HAVE_KERNEL_OPLOCKS_IRIX
#undef HAVE_KERNEL_OPLOCKS_LINUX
#undef HAVE_KERNEL_CHANGE_NOTIFY
#undef HAVE_IRIX_SPECIFIC_CAPABILITIES
#undef HAVE_INT16_FROM_RPC_RPC_H
#undef HAVE_UINT16_FROM_RPC_RPC_H
#undef HAVE_INT32_FROM_RPC_RPC_H
#undef HAVE_UINT32_FROM_RPC_RPC_H
#undef KRB4_AUTH
#undef KRB5_AUTH
#undef SEEKDIR_RETURNS_VOID
#undef HAVE_DIRENT_D_OFF
#undef HAVE_GETSPNAM
#undef HAVE_BIGCRYPT
#undef HAVE_GETPRPWNAM
#undef HAVE_FSTAT64
#undef HAVE_LSTAT64
#undef HAVE_STAT64
#undef HAVE_SETRESGID
#undef HAVE_SETRESGID_DECL
#undef HAVE_SHADOW_H
#undef HAVE_MEMSET
#undef HAVE_STRCASECMP
#undef HAVE_STRUCT_DIRENT64
#undef HAVE_TRUNCATED_SALT
#undef BROKEN_NISPLUS_INCLUDE_FILES
#undef HAVE_RPC_AUTH_ERROR_CONFLICT
#undef HAVE_EXPLICIT_LARGEFILE_SUPPORT
#undef USE_BOTH_CRYPT_CALLS
#undef HAVE_BROKEN_FCNTL64_LOCKS
#undef HAVE_SECURE_MKSTEMP
#undef HAVE_FNMATCH
#undef USE_SETEUID
#undef USE_SETRESUID
#undef USE_SETREUID
#undef USE_SETUIDX
#undef HAVE_DLOPEN
#undef HAVE_DLCLOSE
#undef HAVE_DLSYM
#undef HAVE_DLERROR
#undef SYSCONF_SC_NGROUPS_MAX
#undef HAVE_UT_UT_NAME
#undef HAVE_UT_UT_USER
#undef HAVE_UT_UT_ID
#undef HAVE_UT_UT_HOST
#undef HAVE_UT_UT_TIME
#undef HAVE_UT_UT_TV
#undef HAVE_UT_UT_TYPE
#undef HAVE_UT_UT_PID
#undef HAVE_UT_UT_EXIT
#undef HAVE_UT_UT_ADDR
#undef HAVE_UX_UT_SYSLEN
#undef PUTUTLINE_RETURNS_UTMP
#undef COMPILER_SUPPORTS_LL
#undef HAVE_YP_GET_DEFAULT_DOMAIN
#undef USE_SPINLOCKS
#undef SPARC_SPINLOCKS
#undef INTEL_SPINLOCKS
#undef MIPS_SPINLOCKS
#undef POWERPC_SPINLOCKS
#undef HAVE_POSIX_ACLS
#undef HAVE_ACL_GET_PERM_NP
#undef HAVE_UNIXWARE_ACLS
#undef HAVE_SOLARIS_ACLS
#undef HAVE_HPUX_ACLS
#undef HAVE_IRIX_ACLS
#undef HAVE_AIX_ACLS
#undef HAVE_TRU64_ACLS
#undef HAVE_NO_ACLS
#undef HAVE_LIBPAM
#undef HAVE_ASPRINTF_DECL
#undef HAVE_VASPRINTF_DECL
#undef HAVE_SNPRINTF_DECL
#undef HAVE_VSNPRINTF_DECL
#undef HAVE_UNIXSOCKET
#undef MMAP_BLACKLIST
#undef HAVE_CUPS
#undef WITH_LDAP_SAM
#undef WITH_NISPLUS_SAM
#undef WITH_SMBPASSWD_SAM
#undef WITH_TDB_SAM
#undef LINUX_QUOTAS_1
#undef LINUX_QUOTAS_2
#undef BROKEN_REDHAT_7_SYSTEM_HEADERS
#undef HAVE_IMMEDIATE_STRUCTURES
#undef HAVE_STAT_ST_BLOCKS
#undef STAT_ST_BLOCKSIZE
#undef HAVE_DEVICE_MAJOR_FN
#undef HAVE_DEVICE_MINOR_FN
#undef HAVE_MAKEDEV_FN
#undef HAVE_GETGROUPS_TOO_MANY_EGIDS
/*
 * Add these definitions to allow VFS modules to
 * see the CPPFLAGS defines.
 */
#ifndef _HPUX_SOURCE
#undef _HPUX_SOURCE
#endif
#ifndef _POSIX_SOURCE
#undef _POSIX_SOURCE
#endif
#ifndef _LARGEFILE64_SOURCE
#undef _LARGEFILE64_SOURCE
#endif
#ifndef _ALIGNMENT_REQUIRED
#undef _ALIGNMENT_REQUIRED
#endif
#ifndef _MAX_ALIGNMENT
#undef _MAX_ALIGNMENT
#endif
#ifndef _LARGE_FILES
#undef _LARGE_FILES
#endif
#ifndef _FILE_OFFSET_BITS
#undef _FILE_OFFSET_BITS
#endif
#ifndef _GNU_SOURCE
#undef _GNU_SOURCE
#endif

==> samba-2.2.8a.tar.bz2: samba-2.2.8a/source/acconfig.h <==
#undef HAVE_VOLATILE
#undef HAVE_BROKEN_READDIR
#undef HAVE_C99_VSNPRINTF
#undef HAVE_ERRNO_DECL
#undef HAVE_LONGLONG
#undef HAVE_OFF64_T
#undef HAVE_REMSH
#undef HAVE_UNSIGNED_CHAR
#undef HAVE_UTIMBUF
#undef HAVE_SIG_ATOMIC_T_TYPE
#undef HAVE_SOCKLEN_T_TYPE
#undef ssize_t
#undef ino_t
#undef ssize_t
#undef loff_t
#undef offset_t
#undef aclent_t
#undef wchar_t
#undef HAVE_CONNECT
#undef HAVE_SHORT_INO_T
#undef WITH_SMBWRAPPER
#undef WITH_AFS
#undef WITH_DFS
#undef SUNOS5
#undef SUNOS4
#undef LINUX
#undef AIX
#undef BSD
#undef IRIX
#undef IRIX6
#undef HPUX
#undef QNX
#undef SCO
#undef OSF1
#undef NEXT2
#undef RELIANTUNIX
#undef HAVE_MMAP
#undef HAVE_FCNTL_LOCK
#undef HAVE_FTRUNCATE_EXTEND
#undef FTRUNCATE_NEEDS_ROOT
#undef HAVE_TRAPDOOR_UID
#undef HAVE_ROOT
#undef HAVE_GETTIMEOFDAY_TZ
#undef HAVE_SOCK_SIN_LEN
#undef STAT_READ_FILSYS
#undef STAT_STATFS2_BSIZE
#undef STAT_STATFS2_FSIZE
#undef STAT_STATFS2_FS_DATA
#undef STAT_STATFS3_OSF1
#undef STAT_STATFS4
#undef STAT_STATVFS
#undef STAT_STATVFS64
#undef HAVE_IFACE_AIX
#undef HAVE_IFACE_IFCONF
#undef HAVE_IFACE_IFREQ
#undef HAVE_CRYPT
#undef HAVE_PUTPRPWNAM
#undef HAVE_SET_AUTH_PARAMETERS
#undef WITH_SYSLOG
#undef WITH_PROFILE
#undef WITH_SSL
#undef WITH_LDAP
#undef WITH_NISPLUS
#undef WITH_TDBPWD
#undef WITH_PAM
#undef WITH_PAM_SMBPASS
#undef WITH_NISPLUS_HOME
#undef WITH_AUTOMOUNT
#undef WITH_SMBMOUNT
#undef HAVE_BROKEN_GETGROUPS
#undef REPLACE_GETPASS
#undef REPLACE_INET_NTOA
#undef HAVE_FILE_MACRO
#undef HAVE_FUNCTION_MACRO
#undef HAVE_VA_COPY
#undef HAVE_SETRESUID_DECL
#undef HAVE_SETRESUID
#undef WITH_NETATALK
#undef WITH_UTMP
#undef WITH_MSDFS
#undef WITH_VFS
#undef HAVE_INO64_T
#undef HAVE_DEV64_T
#undef HAVE_STRUCT_FLOCK64
#undef SIZEOF_INO_T
#undef SIZEOF_OFF_T
#undef STAT_STATVFS64
#undef HAVE_LIBREADLINE
#undef HAVE_KERNEL_SHARE_MODES
#undef HAVE_KERNEL_OPLOCKS_IRIX
#undef HAVE_KERNEL_OPLOCKS_LINUX
#undef HAVE_KERNEL_CHANGE_NOTIFY
#undef HAVE_IRIX_SPECIFIC_CAPABILITIES
#undef HAVE_INT16_FROM_RPC_RPC_H
#undef HAVE_UINT16_FROM_RPC_RPC_H
#undef HAVE_INT32_FROM_RPC_RPC_H
#undef HAVE_UINT32_FROM_RPC_RPC_H
#undef KRB4_AUTH
#undef KRB5_AUTH
#undef SEEKDIR_RETURNS_VOID
#undef HAVE_DIRENT_D_OFF
#undef HAVE_GETSPNAM
#undef HAVE_BIGCRYPT
#undef HAVE_GETPRPWNAM
#undef HAVE_FSTAT64
#undef HAVE_LSTAT64
#undef HAVE_STAT64
#undef HAVE_SETRESGID
#undef HAVE_SETRESGID_DECL
#undef HAVE_SHADOW_H
#undef HAVE_MEMSET
#undef HAVE_STRCASECMP
#undef HAVE_STRUCT_DIRENT64
#undef HAVE_TRUNCATED_SALT
#undef BROKEN_NISPLUS_INCLUDE_FILES
#undef HAVE_RPC_AUTH_ERROR_CONFLICT
#undef HAVE_EXPLICIT_LARGEFILE_SUPPORT
#undef USE_BOTH_CRYPT_CALLS
#undef HAVE_BROKEN_FCNTL64_LOCKS
#undef HAVE_SECURE_MKSTEMP
#undef HAVE_FNMATCH
#undef USE_SETEUID
#undef USE_SETRESUID
#undef USE_SETREUID
#undef USE_SETUIDX
#undef HAVE_DLOPEN
#undef HAVE_DLCLOSE
#undef HAVE_DLSYM
#undef HAVE_DLERROR
#undef SYSCONF_SC_NGROUPS_MAX
#undef HAVE_UT_UT_NAME
#undef HAVE_UT_UT_USER
#undef HAVE_UT_UT_ID
#undef HAVE_UT_UT_HOST
#undef HAVE_UT_UT_TIME
#undef HAVE_UT_UT_TV
#undef HAVE_UT_UT_TYPE
#undef HAVE_UT_UT_PID
#undef HAVE_UT_UT_EXIT
#undef HAVE_UT_UT_ADDR
#undef HAVE_UX_UT_SYSLEN
#undef PUTUTLINE_RETURNS_UTMP
#undef COMPILER_SUPPORTS_LL
#undef HAVE_YP_GET_DEFAULT_DOMAIN
#undef USE_SPINLOCKS
#undef SPARC_SPINLOCKS
#undef INTEL_SPINLOCKS
#undef MIPS_SPINLOCKS
#undef POWERPC_SPINLOCKS
#undef HAVE_POSIX_ACLS
#undef HAVE_ACL_GET_PERM_NP
#undef HAVE_UNIXWARE_ACLS
#undef HAVE_SOLARIS_ACLS
#undef HAVE_HPUX_ACLS
#undef HAVE_IRIX_ACLS
#undef HAVE_AIX_ACLS
#undef HAVE_TRU64_ACLS
#undef HAVE_NO_ACLS
#undef HAVE_LIBPAM
#undef HAVE_ASPRINTF_DECL
#undef HAVE_VASPRINTF_DECL
#undef HAVE_SNPRINTF_DECL
#undef HAVE_VSNPRINTF_DECL
#undef HAVE_UNIXSOCKET
#undef MMAP_BLACKLIST
#undef HAVE_CUPS
#undef WITH_LDAP_SAM
#undef WITH_NISPLUS_SAM
#undef WITH_SMBPASSWD_SAM
#undef WITH_TDB_SAM
#undef LINUX_QUOTAS_1
#undef LINUX_QUOTAS_2
#undef BROKEN_REDHAT_7_SYSTEM_HEADERS
#undef HAVE_IMMEDIATE_STRUCTURES
#undef HAVE_STAT_ST_BLOCKS
#undef STAT_ST_BLOCKSIZE
#undef HAVE_DEVICE_MAJOR_FN
#undef HAVE_DEVICE_MINOR_FN
#undef HAVE_MAKEDEV_FN
#undef HAVE_GETGROUPS_TOO_MANY_EGIDS
#undef HAVE_PASSWD_PW_COMMENT
#undef HAVE_PASSWD_PW_AGE
#undef HAVE_STAT_ST_BLKSIZE
#undef WITH_WINBIND_AUTH_CRAP
#undef WITH_HORRIBLE_LDAP_NATIVE_MODE_HACK

/*
 * Add these definitions to allow VFS modules to
 * see the CPPFLAGS defines.
 */
#ifndef _HPUX_SOURCE
#undef _HPUX_SOURCE
#endif
#ifndef _POSIX_SOURCE
#undef _POSIX_SOURCE
#endif
#ifndef _LARGEFILE64_SOURCE
#undef _LARGEFILE64_SOURCE
#endif
#ifndef _ALIGNMENT_REQUIRED
#undef _ALIGNMENT_REQUIRED
#endif
#ifndef _MAX_ALIGNMENT
#undef _MAX_ALIGNMENT
#endif
#ifndef _LARGE_FILES
#undef _LARGE_FILES
#endif
#ifndef _FILE_OFFSET_BITS
#undef _FILE_OFFSET_BITS
#endif
#ifndef _GNU_SOURCE
#undef _GNU_SOURCE
#endif
#undef HAVE_SENDFILE
#undef HAVE_SENDFILE64
#undef LINUX_SENDFILE_API
#undef LINUX_BROKEN_SENDFILE_API
#undef WITH_SENDFILE
#undef FREEBSD_SENDFILE_API
#undef HPUX_SENDFILE_API
#undef HAVE_SENDFILEV
#undef HAVE_SENDFILEV64
#undef SOLARIS_SENDFILE_API
#undef LDAP_SET_REBIND_PROC_ARGS
